"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = void 0;

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _variables = require("../../helpers/variables");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

/**
 * Button Component
 * @type button
 *
 * @prop {boolean} bg: [primary|secondary|dark|primaryLight|white|transparent]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} shadow: add shadow to button?
 * @prop {boolean} rounded: add roundness to the button?
 * @prop {boolean} aspectLocked: make height = width?
 * @prop {boolean} marginTop: add margin to top?
 * @prop {boolean} marginBottom: add margin to bottom?
 * @prop {boolean} marginLeft: add margin to left?
 * @prop {boolean} marginRight: add margin to right?
 * @prop {boolean} sizeLarge: make the button larger?
 * @prop {boolean} sizeSmall: make the button smaller?
 * @prop {boolean} fullWidth: use 100% available width for button?
 * @prop {boolean} noPadding: remove all padding from button?
 * @prop {boolean} uppercase: use UPPERCASE for btn text?
 * @prop {number} fontSize: sets font-size to this if provided
 * @prop {boolean} iconLeft: has icon on the left?
 * @prop {boolean} iconRight: has icon on the right?
 * @prop {number} iconSize: set icon size
 */
var Button = _styledComponents.default.button.withConfig({
  displayName: "styles__Button",
  componentId: "jw4w2x-0"
})(["display:inline-block;background:", ";border:none;box-shadow:", ";border-radius:", ";margin-right:", ";margin-left:", ";margin-top:", ";margin-bottom:", ";padding:", ";width:", ";height:", ";font:", " ", " ", ";color:", ";cursor:pointer;transition:0.25s all ease-in-out;text-transform:", ";line-height:1px;i{position:relative;top:", ";font-weight:", ";font-size:", ";margin-right:", ";margin-left:", ";transition:0.15s all ease-in;}&:hover{opacity:0.9;i{transform:", ";}}@media screen and (max-width:925px){width:", ";width:", ";height:", ";margin:", ";}"], function (props) {
  return props.bgPrimary ? _variables.SCHEME.primary : props.bgSecondary ? _variables.SCHEME.secondary : props.bgDark ? _variables.SCHEME.dark : props.bgPrimaryLight ? _variables.SCHEME.primaryLight : props.bgWhite ? _variables.COLORS.white : props.bgTransparent ? 'transparent' : _variables.SCHEME.gray;
}, function (props) {
  return props.shadow ? '0 2px 4px rgba(0,0,0,0.1)' : 'none';
}, function (props) {
  return props.rounded ? '40px' : '4px';
}, function (props) {
  return !props.noMargin && props.marginRight ? '8px' : '0';
}, function (props) {
  return !props.noMargin && props.marginLeft ? '8px' : '0';
}, function (props) {
  return !props.noMargin && props.marginTop ? '8px' : '0';
}, function (props) {
  return !props.noMargin && props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.aspectLocked || props.noPadding ? '0' : props.sizeLarge ? '14px 2rem' : props.sizeSmall ? '10px 0.75rem' : '10px 1.25rem';
}, function (props) {
  return props.sizeSmall && props.aspectLocked ? '35px' : props.aspectLocked ? '45px' : props.fullWidth ? '100%' : 'auto';
}, function (props) {
  return props.sizeSmall ? '35px' : props.sizeLarge ? '50px' : props.noPadding ? 'auto' : '45px';
}, function (props) {
  return props.weightHeavy || props.uppercase || props.sizeLarge ? '800' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '700';
}, function (props) {
  return props.fontSize ? "".concat(props.fontSize, "px") : props.sizeLarge ? "".concat(_variables.FONT.size - 3, "px") : props.sizeSmall ? "".concat(_variables.FONT.size - 5, "px") : "".concat(_variables.FONT.size - 4, "px");
}, _variables.FONT.family, function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textDark ? _variables.SCHEME.dark : props.textDarker ? _variables.COLORS.darker : props.textPrimaryLight ? _variables.SCHEME.primaryLight : props.textWhite ? _variables.COLORS.white : props.textLight ? _variables.COLORS.light : _variables.SCHEME.gray;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.iconTop ? "".concat(props.iconTop, "px") : '0';
}, function (props) {
  return props.sizeLarge ? '900' : '400';
}, function (props) {
  return props.iconSize ? "".concat(props.iconSize, "px") : '16px';
}, function (props) {
  return props.iconLeft ? '8px' : '0';
}, function (props) {
  return props.iconRight ? '8px' : '0';
}, function (props) {
  return props.iconRight ? 'translateX(2px)' : 'none';
}, function (props) {
  return !props.aspectLocked ? '100%' : 'default';
}, function (props) {
  return props.sizeSmall && props.aspectLocked ? '45px' : props.aspectLocked ? '50px' : '100%';
}, function (props) {
  return props.sizeSmall ? '45px' : props.sizeLarge ? '60px' : props.noPadding ? 'auto' : '50px';
}, function (props) {
  return !props.aspectLocked ? '0.25rem 0' : 'default';
});

exports.Button = Button;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Button, "Button", "/Users/user1/Documents/projects/proponents/src/components/button/styles.js");
  leaveModule(module);
})();

;