"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LabelEl = exports.InputEl = exports.IconEl = exports.InputComponent = exports.InputContainer = void 0;

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _variables = require("../../helpers/variables");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

/**
 * InputContainer
 * Wrapper for label, input, and error message
 * @type div
 *
 * @prop {boolean} inline: display component inline?
 * @prop {string} width: size in px
 * @prop {string} margin: margin for component
 */
var InputContainer = _styledComponents.default.div.withConfig({
  displayName: "styles__InputContainer",
  componentId: "ccd978-0"
})(["max-width:", ";min-width:", ";display:", ";margin:", ";"], function (props) {
  return props.width ? "".concat(props.width, "px") : 'auto';
}, function (props) {
  return props.width ? "".concat(props.width, "px") : 'auto';
}, function (props) {
  return props.inline ? 'inline-block' : 'block';
}, function (props) {
  return props.margin;
});
/**
 * InputComponent
 * Wrapper for input element and the icon
 * @type div
 *
 * @prop {string} split: splits the column in defined format
 * @prop {boolean} bordered: set the border if bordered (has error)
 */


exports.InputContainer = InputContainer;

var InputComponent = _styledComponents.default.div.withConfig({
  displayName: "styles__InputComponent",
  componentId: "ccd978-1"
})(["position:relative;top:5px;display:inline-grid;grid-template-columns:", ";width:100%;grid-gap:1rem;background:", ";height:45px;border-radius:6px;border:1px solid ", ";box-shadow:0 1px 3px #E6EBF1;margin:0 0 0.5rem;padding:0 1rem;transition:0.25s all ease-in;align-items:center;&:focus{box-shadow:0 1px 2px #DFE5ED;}"], function (props) {
  return props.split;
}, _variables.COLORS.white, function (props) {
  return props.bordered ? _variables.ACTIONS.error : 'transparent';
});
/**
 * IconEl
 * Define style for <i.material-icons> element
 *
 * @prop {boolean} error: change icon color to red on error
 */


exports.InputComponent = InputComponent;

var IconEl = _styledComponents.default.i.withConfig({
  displayName: "styles__IconEl",
  componentId: "ccd978-2"
})(["color:", ";font-size:20px;transition:0.25s all ease-in;"], function (props) {
  return props.error ? _variables.ACTIONS.error : _variables.COLORS.lighter;
});
/**
 * InputEl
 * Defines style props for input element
 */


exports.IconEl = IconEl;

var InputEl = _styledComponents.default.input.withConfig({
  displayName: "styles__InputEl",
  componentId: "ccd978-3"
})(["font:400 18px ", ";color:", ";background:transparent;"], _variables.FONT.family, _variables.COLORS.dark);
/**
 * LabelEl
 * Defines style props for label element
 */


exports.InputEl = InputEl;

var LabelEl = _styledComponents.default.label.withConfig({
  displayName: "styles__LabelEl",
  componentId: "ccd978-4"
})(["display:block;margin:2.25rem auto 5px 0;font:500 14px ", ";color:", ";"], _variables.FONT.family, _variables.COLORS.light);

exports.LabelEl = LabelEl;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(InputContainer, "InputContainer", "/Users/user1/Documents/projects/proponents/src/components/input/styles.js");
  reactHotLoader.register(InputComponent, "InputComponent", "/Users/user1/Documents/projects/proponents/src/components/input/styles.js");
  reactHotLoader.register(IconEl, "IconEl", "/Users/user1/Documents/projects/proponents/src/components/input/styles.js");
  reactHotLoader.register(InputEl, "InputEl", "/Users/user1/Documents/projects/proponents/src/components/input/styles.js");
  reactHotLoader.register(LabelEl, "LabelEl", "/Users/user1/Documents/projects/proponents/src/components/input/styles.js");
  leaveModule(module);
})();

;