"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Code = exports.Img = exports.Span = exports.Text = exports.H5 = exports.H4 = exports.H3 = exports.H2 = exports.H1 = exports.GridSection = exports.Section = exports.LinkTag = exports.Page = void 0;

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactRouterDom = require("react-router-dom");

var _variables = require("./variables");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

/**
 * Exporting Styled Components
 */

/**
 * Page Component
 * @type Div
 *
 * @prop {boolean} bgGradientDark: add dark gradient to background?
 * @prop {boolean} bgGradientLight: add light gradient to background?
 * @prop {boolean} bgGray: add gray as background?
 * @prop {boolean} bgDark: add dark as background?
 * @prop {string} bg: custom HEXCODE (#FFFFFF)
 * @prop {string} padding: adds padding to page
 */
var Page = _styledComponents.default.div.withConfig({
  displayName: "global__Page",
  componentId: "wozf93-0"
})(["width:100vw;min-height:100vh;overflow-x:hidden;background:", ";padding:", ";transition:0.25s all ease-in;animation:slideUp 0.25s ease-in forwards;@keyframes slideUp{from{-webkit-transform:translateY(2.5%);transform:translateY(2.5%);opacity:0;}to{-webkit-transform:translateY(0);transform:translateY(0);opacity:1;}}"], function (props) {
  return props.bgWhite ? _variables.COLORS.white : _variables.SCHEME.gray;
}, function (props) {
  return props.padding ? props.padding : '2rem 0 0';
});
/**
 * Link Component
 * @type Link
 */


exports.Page = Page;
var LinkTag = (0, _styledComponents.default)(_reactRouterDom.Link).withConfig({
  displayName: "global__LinkTag",
  componentId: "wozf93-1"
})(["color:", ";"], _variables.SCHEME.primary);
/** ************************************************/

/** ***************** DIV STYLING *****************/

/** ************************************************/

/**
 * Section Component
 * @type Section
 *
 * @prop {string} bg: custom HEXCODE (#FFFFFF)
 * @prop {string} bgMobile: custom HEXCODE for mobile(#FFFFFF)
 * @prop {string} bgURL: use background image?
 * @prop {string} bgGradient: use gradient for background?
 * @prop {boolean} borderTop: adds a border top
 * @prop {boolean} fullHeight: match section height to screen size?
 * @prop {boolean} alignCenter: align text to center?
 * @prop {boolean} alignRight: align text to right?
 * @prop {boolean} borderRight: add border right?
 * @prop {string} padding: add padding to section
 * @prop {string} mobilePadding: add padding to section (on mobile)
 * @prop {string} tabletPadding: add padding to section (on tablets)
 */

exports.LinkTag = LinkTag;

var Section = _styledComponents.default.section.withConfig({
  displayName: "global__Section",
  componentId: "wozf93-2"
})(["background:", ";background-size:cover;background-position:fixed;background-repeat:no-repeat;border-top:", ";border-radius:", ";height:", ";text-align:", ";border-right:", ";padding:", ";@media screen and (max-width:1280px){padding:", ";}@media screen and (max-width:925px){background:", ";padding:", ";}"], function (props) {
  return props.bg && props.bgURL ? "url(".concat(props.bgURL, "), ").concat(props.bg) : props.bgGradient && props.bgURL ? "url(".concat(props.bgURL, "), linear-gradient(").concat(props.bgGradient, ")") : props.bg ? props.bg : props.bgURL ? "url(".concat(props.bgURL, ") no-repeat") : props.bgGradient ? "linear-gradient(".concat(props.bgGradient, ")") : 'none';
}, function (props) {
  return props.borderTop ? props.bg === '#FFFFFF' ? '1px solid #EDEFF5' : '1px solid #E4E5E9' : 'none';
}, function (props) {
  return props.borderRadius ? "".concat(props.borderRadius, "px") : '0';
}, function (props) {
  return props.fullHeight ? '100vh' : 'auto';
}, function (props) {
  return props.alignCenter ? 'center' : props.alignRight ? 'right' : 'left';
}, function (props) {
  return props.borderRight ? "1px solid ".concat(_variables.SCHEME.gray) : 'none';
}, function (props) {
  return props.padding ? props.padding : '0';
}, function (props) {
  return props.tabletPadding ? props.tabletPadding : props.padding;
}, function (props) {
  return props.bgMobile ? props.bgMobile : props.bgGradient ? "linear-gradient(".concat(props.bgGradient, ")") : props.bg ? props.bg : 'none';
}, function (props) {
  return props.mobilePadding ? props.mobilePadding : props.padding;
});
/**
 * GridSection Component
 * @extends Section
 *
 * @prop {string} split: split columns with this config
 * @prop {string} tabletSplit: add split to section (on tablet)
 * @prop {string} mobileSplit: split columns (on mobile)
 * @prop {string} gap: add grid-gap (gutter)
 * @prop {string} tabletGap: add gap to section (on tablet)
 * @prop {string} width: set grid section width
 * @prop {string} tabletWidth: add width to section (on tablet)
 * @prop {string} mobileWidth: set width (on mobile)
 * @prop {string} margin: sets margin to the Grid Section
 * @prop {string} padding: add padding to section
 * @prop {string} mobilePadding: add padding to section (on mobile)
 * @prop {string} tabletPadding: add padding to section (on tablet)
 * @prop {boolean} alignVertically: align items vertically centered?
 * @prop {boolean} alignBottom: align items to bottom?
 * @prop {boolean} justifyCenter: justifies all the children center
 * @prop {boolean} sameHeightChildren: set same height to all children
 */


exports.Section = Section;
var GridSection = (0, _styledComponents.default)(Section).withConfig({
  displayName: "global__GridSection",
  componentId: "wozf93-3"
})(["display:grid;grid-template-columns:", ";grid-gap:", ";padding:", ";grid-auto-rows:", ";width:", ";margin:", ";align-items:", ";justify-items:", ";@media screen and (max-width:1280px){padding:", ";width:", ";grid-template-columns:", ";grid-gap:", ";}@media screen and (max-width:824px){padding:", ";grid-template-columns:", ";grid-gap:", ";width:", ";}"], function (props) {
  return props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.gap ? props.gap : '0';
}, function (props) {
  return props.padding ? props.padding : '0';
}, function (props) {
  return props.sameHeightChildren ? '1fr' : 'auto';
}, function (props) {
  return props.width ? "".concat(props.width, "%") : 'auto';
}, function (props) {
  return props.margin ? props.margin : props.width ? '0 auto' : 'auto';
}, function (props) {
  return props.alignVertically ? 'center' : props.alignBottom ? 'end' : 'start';
}, function (props) {
  return props.justifyCenter ? 'center' : 'stretch';
}, function (props) {
  return props.tabletPadding ? props.tabletPadding : props.padding;
}, function (props) {
  return props.tabletWidth ? "".concat(props.tabletWidth, "%") : 'auto';
}, function (props) {
  return props.tabletSplit ? props.tabletSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.tabletGap ? props.tabletGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobilePadding ? props.mobilePadding : props.padding;
}, function (props) {
  return props.mobileSplit ? props.mobileSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.mobileGap ? props.mobileGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobileWidth ? "".concat(props.mobileWidth, "%") : 'auto';
});
/** ************************************************/

/** ***************** FONT STYLING *****************/

/** ************************************************/

/**
 * H1 Component
 * @type h1
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */

exports.GridSection = GridSection;

var H1 = _styledComponents.default.h1.withConfig({
  displayName: "global__H1",
  componentId: "wozf93-4"
})(["color:", ";font:", " ", "px ", ";text-transform:", ";line-height:", ";font-style:", ";margin-bottom:", ";span{font-weight:", ";}@media screen and (max-width:925px){font-size:", "px;}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textBase ? _variables.COLORS.base : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.dark;
}, function (props) {
  return props.weightBold ? '700' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '800';
}, _variables.FONT.size * 3.25, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.weightBold ? '700' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '800';
}, _variables.FONT.size * 2.5);
/**
 * H2 Component
 * @type h2
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.H1 = H1;

var H2 = _styledComponents.default.h2.withConfig({
  displayName: "global__H2",
  componentId: "wozf93-5"
})(["color:", ";font:", " ", "px ", ";text-transform:", ";line-height:", ";font-style:", ";margin-bottom:", ";span{font-weight:", ";}@media screen and (max-width:925px){font-size:", "px;}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textBase ? _variables.COLORS.base : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.dark;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '700';
}, _variables.FONT.size * 2.75, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.marginBottom ? '16px' : '0';
}, function (props) {
  return props.weightHeavy ? '800' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '700';
}, _variables.FONT.size * 2);
/**
 * H3 Component
 * @type h3
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.H2 = H2;

var H3 = _styledComponents.default.h3.withConfig({
  displayName: "global__H3",
  componentId: "wozf93-6"
})(["color:", ";font:", " ", "px ", ";text-transform:", ";line-height:", ";font-style:", ";margin-bottom:", ";span{font-weight:", ";}@media screen and (max-width:925px){font-size:", "px;}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textBase ? _variables.COLORS.base : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.dark;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '700';
}, _variables.FONT.size * 2, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.weightHeavy ? '800' : props.weightSemiBold ? '600' : props.weightNormal ? '400' : props.weightLight ? '300' : '700';
}, _variables.FONT.size * 1.75);
/**
 * H4 Component
 * @type h4
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.H3 = H3;

var H4 = _styledComponents.default.h4.withConfig({
  displayName: "global__H4",
  componentId: "wozf93-7"
})(["color:", ";font:", " ", "px ", ";text-transform:", ";line-height:", ";font-style:", ";margin-bottom:", ";span{font-weight:", ";}@media screen and (max-width:925px){font-size:", "px;}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textBase ? _variables.COLORS.base : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.dark;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightNormal ? '400' : props.weightLight ? '300' : '600';
}, _variables.FONT.size * 1.5, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightNormal ? '400' : props.weightLight ? '300' : '600';
}, _variables.FONT.size * 1.5);
/**
 * H5 Component
 * @type h5
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.H4 = H4;

var H5 = _styledComponents.default.h5.withConfig({
  displayName: "global__H5",
  componentId: "wozf93-8"
})(["color:", ";font:", " ", "px ", ";text-transform:", ";line-height:", ";font-style:", ";margin-bottom:", ";span{font-weight:", ";}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textBase ? _variables.COLORS.base : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.dark;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightNormal ? '400' : props.weightLight ? '300' : '600';
}, _variables.FONT.size * 1.25, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '100%';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightNormal ? '400' : props.weightLight ? '300' : '600';
});
/**
 * Text Component
 * @type p (paragraph)
 *
 * @prop {boolean} text:
 * [primary|secondary|gray|white|lighter|light|dark|error|success|warning|info|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 * @prop {number} fontSize: set font-size to this if provided
 * @prop {number} lineHeight: set line-height to this if provided
 * @prop {number} width: set width to this if provided
 * @prop {boolean} alignCenter: align <p> to center?
 * @prop {boolean} alignRight: align <p> to right?
 * @prop {boolean} marginCenter: set <p> center, horizontally?
 * @prop {boolean} marginTop: add margin to top?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.H5 = H5;

var Text = _styledComponents.default.p.withConfig({
  displayName: "global__Text",
  componentId: "wozf93-9"
})(["color:", ";font-weight:", ";font-size:", ";font-family:", ";text-transform:", ";font-style:", ";line-height:", ";width:", ";text-align:", ";margin:", ";margin-top:", ";margin-bottom:", ";strong{font-weight:700;}span{font-weight:", ";}a{color:", ";}@media screen and (max-width:925px){width:", ";}"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textDark ? _variables.COLORS.dark : props.textError ? _variables.ACTIONS.error : props.textSuccess ? _variables.ACTIONS.success : props.textWarning ? _variables.ACTIONS.warning : props.textInfo ? _variables.ACTIONS.info : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.base;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightSemiBold ? '600' : props.weightLight ? '300' : '400';
}, function (props) {
  return props.fontSize ? "".concat(props.fontSize, "px") : "".concat(_variables.FONT.size, "px");
}, function (props) {
  return props.logoFont ? 'Carter One' : _variables.FONT.family;
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.italic ? 'italic' : 'none';
}, function (props) {
  return props.lineHeight ? "".concat(props.lineHeight, "%") : '150%';
}, function (props) {
  return props.width ? "".concat(props.width, "%") : 'auto';
}, function (props) {
  return props.alignCenter ? 'center' : props.alignRight ? 'right' : 'left';
}, function (props) {
  return props.marginCenter ? '0 auto' : '0';
}, function (props) {
  return props.marginTop ? "".concat(props.marginTop, "px") : '0';
}, function (props) {
  return props.marginBottom ? '8px' : '0';
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightSemiBold ? '600' : props.weightLight ? '300' : '400';
}, _variables.SCHEME.primary, function (props) {
  return props.mobileWidth ? "".concat(props.mobileWidth, "%") : '100%';
});
/**
 * Span Component
 * @type Span
 *
 * @prop {boolean} text: [primary|secondary|gray|white|lighter|light|base]
 * @prop {boolean} weight: [heavy|bold|semibold|normal|light]
 * @prop {boolean} uppercase: set case to UPPERCASE?
 * @prop {boolean} italic: set case to italic?
 * @prop {boolean} marginBottom: add margin to bottom?
 */


exports.Text = Text;

var Span = _styledComponents.default.span.withConfig({
  displayName: "global__Span",
  componentId: "wozf93-10"
})(["color:", ";font-weight:", ";text-transform:", ";font-style:", ";"], function (props) {
  return props.textPrimary ? _variables.SCHEME.primary : props.textSecondary ? _variables.SCHEME.secondary : props.textGray ? _variables.SCHEME.gray : props.textWhite ? _variables.COLORS.white : props.textLighter ? _variables.COLORS.lighter : props.textLight ? _variables.COLORS.light : props.textDark ? _variables.COLORS.dark : props.darkOpacity ? "rgba(0,0,0,".concat(props.darkOpacity, ")") : props.lightOpacity ? "rgba(255,255,255,".concat(props.lightOpacity, ")") : _variables.COLORS.base;
}, function (props) {
  return props.weightHeavy ? '800' : props.weightBold ? '700' : props.weightSemiBold ? '600' : props.weightLight ? '300' : '400';
}, function (props) {
  return props.uppercase ? 'uppercase' : 'none';
}, function (props) {
  return props.italic ? 'italic' : 'none';
});
/**
 * Img Component
 * @type img
 *
 * @prop {string} display: [block|inline|inline-block]
 * @prop {string} padding: adds padding to image
 * @prop {number} width: set width for image
 * @prop {number} mobileWidth: set width for image in mobile
 * @prop {string | boolean} margin = string; margin[Direction] = boolean
 * @prop {string} mobileMargin: adds margin on mobile
 * @prop {boolean} float: [left|right]
 * @prop {boolean} rounded: makes the image round
 * @prop {boolean} mobileNoDisplay: do not show on mobile
 */


exports.Span = Span;

var Img = _styledComponents.default.img.withConfig({
  displayName: "global__Img",
  componentId: "wozf93-11"
})(["display:", ";padding:", ";width:", ";height:", ";border-radius:", ";margin:", ";float:", ";filter:", ";@media screen and (max-width:925px){display:", ";width:", ";margin:", ";}"], function (props) {
  return props.display ? props.display : 'inline-block';
}, function (props) {
  return props.padding ? props.padding : '0';
}, function (props) {
  return props.width && typeof props.width === 'number' ? "".concat(props.width, "%") : props.width && typeof props.width === 'string' ? "".concat(props.width, "px") : 'auto';
}, function (props) {
  return props.height ? "".concat(props.height, "px") : 'auto';
}, function (props) {
  return props.rounded ? '50%' : props.radius ? props.radius : '0';
}, function (props) {
  return props.margin ? props.margin : props.width ? "0 ".concat((100 - props.width) / 2, "%") : props.marginLeft ? '0 auto 0 0' : props.marginRight ? '0 0 0 auto' : '0 auto';
}, function (props) {
  return props.floatLeft ? 'left' : props.floatRight ? 'right' : 'none';
}, function (props) {
  return props.grayscale ? 'grayscale(100%)' : 'none';
}, function (props) {
  return props.mobileNoDisplay ? 'none' : props.display ? props.display : 'inline-block';
}, function (props) {
  return props.mobileWidth ? "".concat(props.mobileWidth, "px") : '100%';
}, function (props) {
  return props.mobileMargin ? props.mobileMargin : '0';
});
/**
 * Code component
 * @type code
 */


exports.Img = Img;

var Code = _styledComponents.default.code.withConfig({
  displayName: "global__Code",
  componentId: "wozf93-12"
})(["background:", ";color:", ";padding:2px 6px;border-radius:4px;font-weight:600;font-family:Inconsolata;"], _variables.SCHEME.primaryLight, _variables.SCHEME.primary);

exports.Code = Code;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Page, "Page", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(LinkTag, "LinkTag", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Section, "Section", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(GridSection, "GridSection", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H1, "H1", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H2, "H2", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H3, "H3", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H4, "H4", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(H5, "H5", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Text, "Text", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Span, "Span", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Img, "Img", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(Code, "Code", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  leaveModule(module);
})();

;